@@ -1,5 +1,6 @@
 <?php
 namespace LAM\CONFIG;
+use htmlJavaScript;
 use \moduleCache;
 use \htmlSpacer;
 use \htmlTable;
@@ -115,7 +116,7 @@ for ($i = 0; $i < sizeof($errorsToDisplay); $i++) {
 	call_user_func_array('StatusMessage', $errorsToDisplay[$i]);
 }
 
-echo "<form id=\"inputForm\" action=\"moduleSettings.php\" method=\"post\" autocomplete=\"off\" onSubmit=\"saveScrollPosition('inputForm')\" novalidate=\"novalidate\">\n";
+echo "<form id=\"inputForm\" action=\"moduleSettings.php\" method=\"post\" autocomplete=\"off\" onSubmit=\"window.lam.utility.saveScrollPosition('inputForm')\" novalidate=\"novalidate\">\n";
 
 printConfigurationPageTabs(ConfigurationPageTab::MODULE_SETTINGS);
 
@@ -186,18 +187,14 @@ $buttonContainer->addElement($saveButton);
 $cancelButton = new htmlButton('cancelSettings', _('Cancel'));
 $buttonContainer->addElement($cancelButton, true);
 $buttonContainer->addElement(new htmlSpacer(null, '10px'), true);
-parseHtml(null, $buttonContainer, [], false, null);
 
-if ((sizeof($errorsToDisplay) == 0) && isset($_POST['scrollPositionTop']) && isset($_POST['scrollPositionLeft'])) {
+if (empty($errorsToDisplay) && isset($_POST['scrollPositionTop']) && isset($_POST['scrollPositionLeft'])) {
 	// scroll to last position
-	echo '<script type="text/javascript">
-		jQuery(document).ready(function() {
-			jQuery(window).scrollTop(' . $_POST['scrollPositionTop'] . ');
-			jQuery(window).scrollLeft('. $_POST['scrollPositionLeft'] . ');
-	});
-	</script>';
+	$buttonContainer->addElement(new htmlJavaScript('window.lam.utility.restoreScrollPosition(' . $_POST['scrollPositionTop'] .', ' . $_POST['scrollPositionLeft'] . ')'));
 }
 
+parseHtml(null, $buttonContainer, [], false, null);
+
 echo "</form>\n";
 echo "</body>\n";
 echo "</html>\n";
