@@ -1,5 +1,6 @@
 <?php
 namespace LAM\TOOLS\PDF_EDITOR;
+use htmlJavaScript;
 use \htmlResponsiveRow;
 use \htmlResponsiveSelect;
 use \htmlResponsiveInputField;
@@ -24,7 +25,7 @@ use LAMException;
 /*
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2007 - 2023  Roland Gruber
+                2007 - 2024  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -128,6 +129,7 @@ if (!isset($_SESSION['currentPDFStructure'])) {
 		}
 	}
 	catch (LAMException $e) {
+		logNewMessage(LOG_ERR, $e->getTitle());
 		metaRefresh('pdfmain.php?loadFailed=1&name=' . $_GET['edit']);
 		exit;
 	}
@@ -240,7 +242,7 @@ if (isset($_SESSION['currentPDFStructure'])) {
 }
 
 ?>
-	<form id="inputForm" action="pdfpage.php" method="post" onSubmit="saveScrollPosition('inputForm')">
+	<form id="inputForm" action="pdfpage.php" method="post" onSubmit="window.lam.utility.saveScrollPosition('inputForm')">
 <?php
 $sectionElements = [];
 $nonTextSectionElements = [];
@@ -471,18 +473,13 @@ $buttonContainer->add(new htmlHiddenInput('form_submit', 'true'), 4);
 $container->add($buttonContainer, 12);
 addSecurityTokenToMetaHTML($container);
 
-parseHtml(null, $container, [], false, $type->getScope());
-
 if ((sizeof($saveErrors) == 0) && isset($_POST['scrollPositionTop']) && isset($_POST['scrollPositionLeft'])) {
 	// scroll to last position
-	echo '<script type="text/javascript">
-		jQuery(document).ready(function() {
-			jQuery(window).scrollTop(' . $_POST['scrollPositionTop'] . ');
-			jQuery(window).scrollLeft('. $_POST['scrollPositionLeft'] . ');
-	});
-	</script>';
+	$container->add(new htmlJavaScript('window.lam.utility.restoreScrollPosition(' . $_POST['scrollPositionTop'] .', ' . $_POST['scrollPositionLeft'] . ')'));
 }
 
+parseHtml(null, $container, [], false, $type->getScope());
+
 echo '</form></div>';
 include __DIR__ . '/../../lib/adminFooter.inc';
 
